@@ -1,12 +1,8 @@
-import time
-
-
 def fubonachi(limit=1):
     a = 0
     b = 1
-    res = [0]
+    res = [0, 1]
     for i in range(limit):
-        res.append(a * b)
         a, b = b, a + b
-        time.sleep(1)
+        res.append(b)
     return res
